@@ -7,7 +7,7 @@ everything out to disk.
 from __future__ import absolute_import
 from __future__ import unicode_literals
 
-__version__ = "2.0"
+__version__ = "2.1"
 
 import __builtin__
 import os
@@ -23,7 +23,7 @@ except ImportError:
 
 class JSONStore(UserDict.DictMixin):
 
-    def __init__(self, path, json_kw=None):
+    def __init__(self, path, json_kw=None, mode=0600):
         """Create a JSONStore object backed by the file at `path`.
 
         If a dict is passed in as `json_kw`, it will be used as keyword
@@ -31,6 +31,7 @@ class JSONStore(UserDict.DictMixin):
         """
         self.path = path
         self.json_kw = json_kw or {}
+        self.mode = mode
 
         self._data = {}
 
@@ -82,6 +83,8 @@ class JSONStore(UserDict.DictMixin):
 
         with self._mktemp() as fp:
             json.dump(self._data, fp, **json_kw)
+        if self.mode != 0600:  # _mktemp uses 0600 by default
+            os.chmod(fp.name, self.mode)
         shutil.move(fp.name, self.path)
 
         self._synced_json_kw = json_kw
@@ -89,5 +92,4 @@ class JSONStore(UserDict.DictMixin):
         return True
 
 
-def open(path, json_kw=None):
-    return JSONStore(path, json_kw)
+open = JSONStore
